@@ -13,20 +13,14 @@ original map projection instead of relying on pcolormesh and a map
 transformation.
 """
 
-import os
-import urllib.request
-
 import cartopy.crs as ccrs
 import matplotlib.pyplot as plt
 
 import xarray as xr
 
-# Download the file from rasterio's repository
-url = 'https://github.com/mapbox/rasterio/raw/master/tests/data/RGB.byte.tif'
-urllib.request.urlretrieve(url, 'RGB.byte.tif')
-
 # Read the data
-da = xr.open_rasterio('RGB.byte.tif')
+url = 'https://github.com/mapbox/rasterio/raw/master/tests/data/RGB.byte.tif'
+da = xr.open_rasterio(url)
 
 # The data is in UTM projection. We have to set it manually until
 # https://github.com/SciTools/cartopy/issues/813 is implemented
@@ -37,6 +31,3 @@ ax = plt.subplot(projection=crs)
 da.plot.imshow(ax=ax, rgb='band', transform=crs)
 ax.coastlines('10m', color='r')
 plt.show()
-
-# Delete the file
-os.remove('RGB.byte.tif')
