@@ -1,13 +1,14 @@
 """Coders for individual Variable objects."""
-from typing import Any
 import warnings
 from functools import partial
+from typing import Any
 
 import numpy as np
 import pandas as pd
 
 from ..core import dtypes, duck_array_ops, indexing
 from ..core.pycompat import dask_array_type
+from ..core.utils import equivalent
 from ..core.variable import Variable
 
 
@@ -15,7 +16,7 @@ class SerializationWarning(RuntimeWarning):
     """Warnings about encoding/decoding issues in serialization."""
 
 
-class VariableCoder(object):
+class VariableCoder:
     """Base class for encoding and decoding transformations on variables.
 
     We use coders for transforming variables between xarray's data model and
@@ -32,12 +33,12 @@ class VariableCoder(object):
     variables in the underlying store.
     """
 
-    def encode(self, variable, name=None):
+    def encode(self, variable, name=None):  # pragma: no cover
         # type: (Variable, Any) -> Variable
         """Convert an encoded variable to a decoded variable."""
         raise NotImplementedError
 
-    def decode(self, variable, name=None):
+    def decode(self, variable, name=None):  # pragma: no cover
         # type: (Variable, Any) -> Variable
         """Convert an decoded variable to a encoded variable."""
         raise NotImplementedError
@@ -145,11 +146,24 @@ class CFMaskCoder(VariableCoder):
     def encode(self, variable, name=None):
         dims, data, attrs, encoding = unpack_for_encoding(variable)
 
-        if encoding.get('_FillValue') is not None:
+        fv = encoding.get('_FillValue')
+        mv = encoding.get('missing_value')
+
+        if fv is not None and mv is not None and not equivalent(fv, mv):
+            raise ValueError("Variable {!r} has multiple fill values {}. "
+                             "Cannot encode data. "
+                             .format(name, [fv, mv]))
+
+        if fv is not None:
             fill_value = pop_to(encoding, attrs, '_FillValue', name=name)
             if not pd.isnull(fill_value):
                 data = duck_array_ops.fillna(data, fill_value)
 
+        if mv is not None:
+            fill_value = pop_to(encoding, attrs, 'missing_value', name=name)
+            if not pd.isnull(fill_value) and fv is None:
+                data = duck_array_ops.fillna(data, fill_value)
+
         return Variable(dims, data, attrs, encoding)
 
     def decode(self, variable, name=None):
