@@ -37,8 +37,17 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-
+from distutils.version import LooseVersion
 import numpy as np
+import pandas as pd
+
+
+# allow ourselves to type checks for Panel even after it's removed
+if LooseVersion(pd.__version__) < '0.25.0':
+    Panel = pd.Panel
+else:
+    class Panel:  # type: ignore
+        pass
 
 
 # for pandas 0.19
@@ -57,15 +66,15 @@ def remove_unused_levels(self):
     --------
     >>> i = pd.MultiIndex.from_product([range(2), list('ab')])
     MultiIndex(levels=[[0, 1], ['a', 'b']],
-               labels=[[0, 0, 1, 1], [0, 1, 0, 1]])
+               codes=[[0, 0, 1, 1], [0, 1, 0, 1]])
     >>> i[2:]
     MultiIndex(levels=[[0, 1], ['a', 'b']],
-               labels=[[1, 1], [0, 1]])
+               codes=[[1, 1], [0, 1]])
     The 0 from the first level is not represented
     and can be removed
     >>> i[2:].remove_unused_levels()
     MultiIndex(levels=[[1], ['a', 'b']],
-               labels=[[0, 0], [0, 1]])
+               codes=[[0, 0], [0, 1]])
     """
     import pandas.core.algorithms as algos
 
